@@ -5,7 +5,7 @@ from ..client import Client
 
 class Reports(Client):
 
-    def request_report(self, record_type, params):
+    def request_report(self, record_type, data):
         self.uri_path = "/v2/hsa/{}/report".format(record_type)
         self.method = "post"
         self.data = params
@@ -20,3 +20,10 @@ class Reports(Client):
         self.method = "get"
         return self.execute_download(location)
 
+    def get_report_download(self, report_id):
+        self.uri_path = "/v2/reports/{}/download".format(report_id)
+        self.method = "get"
+        self.headers.pop("Content-Type")
+        self.headers["Accept-encoding"] = "gzip"
+        return self.execute()
+
